#include <BLEDevice.h>
#include <BLEUtils.h>
#include <BLEServer.h>

// See the following for generating UUIDs:
// https://www.uuidgenerator.net/

#define SERVICE_UUID        "4fafc201-1fb5-459e-8fcc-c5c9c331914b"
#define CHARACTERISTIC_UUID "beb5483e-36e1-4688-b7f5-ea07361b26a8"

#define LEFT_PIN D1
#define RIGHT_PIN D2
#define LAUNCH_PIN D3


class MyCallbacks: public BLECharacteristicCallbacks {
	void onWrite(BLECharacteristic *pCharacteristic) {
		std::string value = pCharacteristic->getValue();

		if (value == "left") {
			Serial.println("received: left");
			digitalWrite(LEFT_PIN, LOW);
		}
		else if (value == "right") {
			Serial.println("received: right");
			digitalWrite(RIGHT_PIN, LOW);
		}
		else if (value == "launch") {
			Serial.println("received: launch");
			digitalWrite(LAUNCH_PIN, LOW);
		}
	}
};

void setup() {
	// set up the pins
	pinMode(LEFT_PIN, INPUT_PULLUP);
	pinMode(RIGHT_PIN, INPUT_PULLUP);
	pinMode(LAUNCH_PIN, INPUT_PULLUP);

	// start the serial console
	Serial.begin(115200);
	delay(5000);
	Serial.println("The Scrambler waiting for commands...");

	// Initialize the bluetooth service
  BLEDevice::init("Pieter's ESP");
  BLEServer *pServer = BLEDevice::createServer();

  BLEService *pService = pServer->createService(SERVICE_UUID);

  BLECharacteristic *pCharacteristic = pService->createCharacteristic(
                                         CHARACTERISTIC_UUID,
                                         BLECharacteristic::PROPERTY_READ |
                                         BLECharacteristic::PROPERTY_WRITE
                                       );

	// set callback for when we receive something
  pCharacteristic->setCallbacks(new MyCallbacks());

	// start the service
  pCharacteristic->setValue("Server Machine");
  pService->start();

	// advertize the server
	BLEAdvertising *pAdvertising = BLEDevice::getAdvertising();
  pAdvertising->addServiceUUID(SERVICE_UUID);
  pAdvertising->setScanResponse(true);
  pAdvertising->setMinPreferred(0x06);  // functions that help with iPhone connections issue
  pAdvertising->setMinPreferred(0x12);
  BLEDevice::startAdvertising();

}

void loop() {
  // put your main code here, to run repeatedly:
  delay(10000);
	//Serial.println("something's happening");
}

